==> jc-1.4.0.tar.gz: polyglot/util/Overrun.h <==
// class polyglot.util.Overrun

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 2c5790ce4f46ee0c polyglot_util_Overrun

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_polyglot_util_Overrun_H_
#define _JC_polyglot_util_Overrun_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_util_Overrun$object;

// Typedefs
typedef struct _jc_polyglot_util_Overrun$sub_refs	_jc_polyglot_util_Overrun$sub_refs;
typedef struct _jc_polyglot_util_Overrun$sub_nonrefs	_jc_polyglot_util_Overrun$sub_nonrefs;
typedef struct _jc_polyglot_util_Overrun$refs	_jc_polyglot_util_Overrun$refs;
typedef struct _jc_polyglot_util_Overrun$nonrefs	_jc_polyglot_util_Overrun$nonrefs;
typedef struct _jc_polyglot_util_Overrun$object	_jc_polyglot_util_Overrun$object;

typedef struct _jc_polyglot_util_Overrun$fields_struct	_jc_polyglot_util_Overrun$fields_struct;
typedef const struct _jc_polyglot_util_Overrun$vmethods	_jc_polyglot_util_Overrun$vmethods;
typedef const struct _jc_polyglot_util_Overrun$vtable	_jc_polyglot_util_Overrun$vtable;
typedef const struct _jc_polyglot_util_Overrun$vtype	_jc_polyglot_util_Overrun$vtype;

// Class fields structure
struct _jc_polyglot_util_Overrun$fields_struct {
	struct _jc_polyglot_util_Overrun$object	*overrun;
};
extern _jc_polyglot_util_Overrun$fields_struct _jc_polyglot_util_Overrun$class_fields;

// Constructors
extern void _jc_polyglot_util_Overrun$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_Overrun$object *);

// Static methods
extern void _jc_polyglot_util_Overrun$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_polyglot_util_Overrun$object *_jc_polyglot_util_Overrun$method$overrun$3f4b61974896a4c0(_jc_env *, jint);

// Virtual methods structure
struct _jc_polyglot_util_Overrun$vmethods {
};

// Vtable
struct _jc_polyglot_util_Overrun$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_polyglot_util_Overrun$vmethods	polyglot_util_Overrun;
};

// Vtype
struct _jc_polyglot_util_Overrun$vtype {
	_jc_type			type;
	_jc_polyglot_util_Overrun$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_Overrun$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_util_Overrun$refs {
    _jc_polyglot_util_Overrun$sub_refs	polyglot_util_Overrun;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_Overrun$sub_nonrefs {
	jint	amount;
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_Overrun$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_polyglot_util_Overrun$sub_nonrefs	polyglot_util_Overrun;
};

// Object instance structure
struct _jc_polyglot_util_Overrun$object {
	_jc_polyglot_util_Overrun$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_Overrun$vtype	*vtype;
	_jc_polyglot_util_Overrun$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_Overrun$vtype _jc_polyglot_util_Overrun$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_Overrun, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_Overrun$class_object;

#endif	/* _JC_polyglot_util_Overrun_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/Overrun.h <==
// class polyglot.util.Overrun

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 2c5790ce4f46ee0c polyglot_util_Overrun

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_polyglot_util_Overrun_H_
#define _JC_polyglot_util_Overrun_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_util_Overrun$object;

// Typedefs
typedef struct _jc_polyglot_util_Overrun$sub_refs	_jc_polyglot_util_Overrun$sub_refs;
typedef struct _jc_polyglot_util_Overrun$sub_nonrefs	_jc_polyglot_util_Overrun$sub_nonrefs;
typedef struct _jc_polyglot_util_Overrun$refs	_jc_polyglot_util_Overrun$refs;
typedef struct _jc_polyglot_util_Overrun$nonrefs	_jc_polyglot_util_Overrun$nonrefs;
typedef struct _jc_polyglot_util_Overrun$object	_jc_polyglot_util_Overrun$object;

typedef struct _jc_polyglot_util_Overrun$fields_struct	_jc_polyglot_util_Overrun$fields_struct;
typedef const struct _jc_polyglot_util_Overrun$vmethods	_jc_polyglot_util_Overrun$vmethods;
typedef const struct _jc_polyglot_util_Overrun$vtable	_jc_polyglot_util_Overrun$vtable;
typedef const struct _jc_polyglot_util_Overrun$vtype	_jc_polyglot_util_Overrun$vtype;

// Class fields structure
struct _jc_polyglot_util_Overrun$fields_struct {
	struct _jc_polyglot_util_Overrun$object	*overrun;
};
extern _jc_polyglot_util_Overrun$fields_struct _jc_polyglot_util_Overrun$class_fields;

// Constructors
extern void _jc_polyglot_util_Overrun$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_Overrun$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_polyglot_util_Overrun$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_util_Overrun$object *_jc_polyglot_util_Overrun$method$overrun$3f4b61974896a4c0(_jc_env *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_util_Overrun$vmethods {
};

// Vtable
struct _jc_polyglot_util_Overrun$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_polyglot_util_Overrun$vmethods	polyglot_util_Overrun;
};

// Vtype
struct _jc_polyglot_util_Overrun$vtype {
	_jc_type			type;
	_jc_polyglot_util_Overrun$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_Overrun$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_util_Overrun$refs {
    _jc_polyglot_util_Overrun$sub_refs	polyglot_util_Overrun;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_Overrun$sub_nonrefs {
	jint	amount;
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_Overrun$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_polyglot_util_Overrun$sub_nonrefs	polyglot_util_Overrun;
};

// Object instance structure
struct _jc_polyglot_util_Overrun$object {
	_jc_polyglot_util_Overrun$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_Overrun$vtype	*vtype;
	_jc_polyglot_util_Overrun$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_Overrun$vtype _jc_polyglot_util_Overrun$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_Overrun, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_Overrun$class_object;

#endif	/* _JC_polyglot_util_Overrun_H_ */
